==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-kbindicator/kbindicator_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>Content</name>
    <message>
        <location filename="../../../src/content.cpp" line="43"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="46"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation>CapsLock</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="50"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="52"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation>NumLock</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="57"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="59"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation>ScrollLock</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="90"/>
        <source>Layout</source>
        <translation>Kiosztás</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="90"/>
        <source>Variant</source>
        <translation>Változat</translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <source>Keyboard indicator settings</source>
        <translation type="vanished">Billentyűzetjelző beállítás</translation>
    </message>
    <message>
        <source>LEDs</source>
        <translation type="vanished">LED-ek</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation>Caps Lock be</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation>Num Lock be</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation>Scroll Lock be</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="102"/>
        <source>Configure layouts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show keyboard layout</source>
        <translation type="vanished">Billentyűzet kiosztás be</translation>
    </message>
    <message>
        <source>Show flags instead labels</source>
        <translation type="vanished">Betű helyett zászló</translation>
    </message>
    <message>
        <source>Layout mode:</source>
        <translation type="vanished">KIjelző mód:</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation>Globális</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation>Ablak</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation>Alkalmazás</translation>
    </message>
    <message>
        <source>Configure layouts...</source>
        <translation type="vanished">Kijelzés beállítása...</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-panel/plugin-kbindicator/kbindicator_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>Content</name>
    <message>
        <location filename="../../../src/content.cpp" line="43"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="46"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation>CapsLock</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="50"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="52"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation>NumLock</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="57"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="59"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation>ScrollLock</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="90"/>
        <source>Layout</source>
        <translation>Kiosztás</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="90"/>
        <source>Variant</source>
        <translation>Változat</translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <source>Keyboard indicator settings</source>
        <translation type="vanished">Billentyűzetjelző beállítás</translation>
    </message>
    <message>
        <source>LEDs</source>
        <translation type="vanished">LED-ek</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation>Billentyűállapot beállítás</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation>Jelzőállapotok</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation>Caps Lock be</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation>Num Lock be</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation>Scroll Lock be</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation>Billentyűkiosztás jelző</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation>Őrváltó</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="102"/>
        <source>Configure layouts</source>
        <translation>Kiosztásbeállítás</translation>
    </message>
    <message>
        <source>Show keyboard layout</source>
        <translation type="vanished">Billentyűzet kiosztás be</translation>
    </message>
    <message>
        <source>Show flags instead labels</source>
        <translation type="vanished">Betű helyett zászló</translation>
    </message>
    <message>
        <source>Layout mode:</source>
        <translation type="vanished">KIjelző mód:</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation>Globális</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation>Ablak</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation>Alkalmazás</translation>
    </message>
    <message>
        <source>Configure layouts...</source>
        <translation type="vanished">Kijelzés beállítása...</translation>
    </message>
</context>
</TS>
